(* ***
comments/questions:

- 24Feb2009: included exact matching coefficients from Luminita.

- 04Apr2006: new (corrected) version of beta2[] included and
  files in data and the plots generated.

- B0[] with 'Integer' arguments?
  If integer values are assigned to the masses the function B0fin is 
  not evaluated.

- Q: how to transfer "global variables" in package ?
- include appr/exact results: how to organize ?
- include "a" and "b" approximation ?

- case-recognition for approximation where not all masses are present?
  -> specify all degenerate masses

- A2a: S2 (not yet defined in decSUSY.m)
           
- 3D-plot in PAW (?)

- "realistic" scales for \mu^intermediate and \mu^GUT

- Note: AlphasSUSY[] contains beta function in DR-bar scheme. Thus
        for three-loop running the result differs from
        AlphasExact[] even for ns=ng=0
*** *)

(* ------------------------------------------------------------ *)

(*--#[ Package: RunDecSUSY *)

BeginPackage["RunDecSUSY`"]

Asp2AsExact::usage = 
    "Same as Asp2As, but uses no approximation (except degenerate 
light squarks. Needs Xt as additional input.";
Asp2As::usage = 
    "Asp2As[alphas, mu, s2thetat, nloops, masses] computes
alphas^(n)(mu) from the knowledge of alphas^(m)(mu), where 
m and n are determined from the masses provided in the list 
masses. The decoupling is performed to nloops order.
s2thetat is the square of the sine of the mxing angle in the top system.";

AlphasSUSY::usage = 
    "AlphasSUSY[alphas, mu0, mu, nf, ns, ng, nloops] computes 
alphas(mu) form alphas(mu0) assuming nf active quarks, ns active
squarks (pairs). ng=0 or ng=1 determines whether the 
gluino is active. The running is performed with nloops accuracy.";

Begin["`Private`"];

(*--#[ some definitions: *)

(* ---------- *)

(* verbose (1) or silent (0) mode: *)
$verbose=0;

(* Path from which results are loaded: *)
respathexact = Global`H3Prefix<>"/RunDec/include/zeta_exact";
respath = Global`H3Prefix<>"/RunDec/include/zeta_appro";

(* requested numerical precision: *)
$NumPrec=20;

(* ---------- *)

(*--#[ Misc.: *)

PrintVerb[ex__] := If[$verbose===1, Print[ex]];

num1 = {cf->4/3,ca->3,tr->1/2};
num2 = {z2->Zeta[2]};

logrep = {lMsquark->Log[mu^2/Msquark^2],
          lMgluino->Log[mu^2/Mgluino^2],
          lMstop1 ->Log[mu^2/Mstop1^2],
	  lMstop2 ->Log[mu^2/Mstop2^2],
	  lMtop   ->Log[mu^2/Mtop^2]};

(phidenrep = {phi1MtgM1g -> phi1[Mtop^2/Mgluino^2,Mstop1^2/Mgluino^2],
	      phi1MtgM2g -> phi1[Mtop^2/Mgluino^2,Mstop2^2/Mgluino^2],
	      deng1t     -> den[Mgluino,Mstop1,Mtop],
	      deng2t     -> den[Mgluino,Mstop2,Mtop],
	      B0fin1tg   -> B0fin[Mstop1,Mtop,Mgluino],
	      B0fin2tg   -> B0fin[Mstop2,Mtop,Mgluino],
	      B0fing1t   -> B0fin[Mgluino,Mstop1,Mtop],
	      B0fing2t   -> B0fin[Mgluino,Mstop2,Mtop],
	      B0fintg1   -> B0fin[Mtop,Mgluino,Mstop1],
	      B0fintg2   -> B0fin[Mtop,Mgluino,Mstop2]
});

den[M1_,M2_,M3_] := 1/((M1-M2-M3)*(M1+M2-M3)*(M1-M2+M3)*(M1+M2+M3));

(*--#] *)
(*--#[ \phi_1: *)

lam2[x_,y_] := (1-x-y)^2-4*x*y;

(phi1[x_,y_] := 1/Sqrt[lam2[x,y]]*
 ( 2*Log[(1+x-y-Sqrt[lam2[x,y]])/2]*Log[(1-x+y-Sqrt[lam2[x,y]])/2]
  -Log[x]*Log[y]
  -2*PolyLog[2,(1+x-y-Sqrt[lam2[x,y]])/2]
  -2*PolyLog[2,(1-x+y-Sqrt[lam2[x,y]])/2]
  +Pi^2/3 )
 );

(*--#] *)
(*--#[ B0fin: *)

(* B_0 = 1/ep + B_0^fin + ep*... *)
(* NOTE: only real part implemented: *)

(B0fin[q2_Real,ma_Real,mb_Real] := Module[
    {outstring},
    If[q2 <= (ma-mb)^2, Return[B0fin1[q2,ma,mb]]];
    If[(q2 >= (ma-mb)^2) && (q2 <= (ma+mb)^2),Return[B0fin2[q2,ma,mb]]];
    If[q2 >= (ma+mb)^2, Return[B0fin3[q2,ma,mb]]];
    outstring = "B0fin["<>ToString[q2]<>","<>ToString[ma]<>
	","<>ToString[mb]<>"]: case not implemented";
    Return[outstring];
]);

(* q2 <= (ma-mb)^2: *)

(B0fin1[q2_,ma_,mb_] := 
    (2-Log[ma*mb/mu2]+(ma^2-mb^2)/q2*Log[mb/ma]
     + Sqrt[(ma+mb)^2-q2]*Sqrt[(ma-mb)^2-q2]/q2 *
     Log[  (Sqrt[(ma+mb)^2-q2]+Sqrt[(ma-mb)^2-q2]) /
           (Sqrt[(ma+mb)^2-q2]-Sqrt[(ma-mb)^2-q2]) ]
     ));

(* (ma-mb)^2 <= q2 <= (ma+mb)^2: *)

(B0fin2[q2_,ma_,mb_] := 
    (2-Log[ma*mb/mu2]+(ma^2-mb^2)/q2*Log[mb/ma]
     - 2*Sqrt[(ma+mb)^2-q2]*Sqrt[q2-(ma-mb)^2]/q2 *
     ArcTan[ Sqrt[q2-(ma-mb)^2]/Sqrt[(ma+mb)^2-q2] ]
     ));

(* q2 >= (ma+mb)^2: *)

(B0fin3[q2_,ma_,mb_] :=
    (2-Log[ma*mb/mu2]+(ma^2-mb^2)/q2*Log[mb/ma]
     - Sqrt[q2-(ma+mb)^2]*Sqrt[q2-(ma-mb)^2]/q2 *
     Log[ - (Sqrt[q2-(ma+mb)^2]+Sqrt[q2-(ma-mb)^2]) /
            (Sqrt[q2-(ma+mb)^2]-Sqrt[q2-(ma-mb)^2]) ]
     ));

(*--#] *)
(*--#[ \beta function: *)

(* 
    Definition as in eq. (2.35) MS, Phys.Rep.364(2002) 
    SUSY formula extrated from
    Jack, Jones, North, hep-ph/9606323 Eq. (14).

    three-loop formula for SM contribution in 
    DR-scheme from Z.Bern et al., PRD66/085002/2002, Eq.(8.19-8.20).
*)

(* 
 ng = # active gluino,
 ns = # active squark flavours,
 nf = # active quark flavours;

 Relations valid for the assumptions:
 1: ng=1 for any ns=!=0   
 2: if a squark flavour is active, its corresponding quark 
 flavour is also active.
 <=>  "ng"- and "nf"-terms comprise only contributions from 
      gluon-gluino-gluino, and respectively, 
      quark-antiquark-gluon vertices.
      "ns"-terms comprise also contributions from
      quark-squark-gluino vertices!
*)

 
beta[0,ng_,nf_,ns_]=1/4*(11/3*ca - 2/3*ca*ng 
                         -2/3*tr*ns - 4/3*tr*nf);

beta[1,ng_,nf_,ns_]=1/16*(34/3*ca^2 -  16/3*ca^2*ng 
                        - 2*(2*cf*tr + 10/3*ca*tr)*nf 
       - 2*(2*cf*tr -  4/3*ca*tr)*ns);

(* *** Use of old result from Bern et al.:
beta[2,ng_,nf_,ns_]=1/64*(3115/54*ca^3 - 1981/54*ca^3*ng 
    - (-2*cf^2*tr + 259/9*ca*cf*tr + 1439/27*ca^2*tr)*nf
                    + (68/9*cf*tr^2 + 158/27*ca*tr^2)*nf^2
     + (14*cf^2*tr - 209/9*ca*cf*tr + 899/27*ca^2*tr)*ns
                    + (148/9*cf*tr^2 - 50/27*ca*tr^2)*ns^2);
*** *)

beta[2,ng_,nf_,ns_]:=1/64*(3115/54*ca^3 - 1981/54*ca^3*ng 
                         - (2*cf^2*tr + 229/9*ca*cf*tr + 1439/27*ca^2*tr)*nf
                         + (80/9*cf*tr^2 + 158/27*ca*tr^2)*nf^2
                         + (18*cf^2*tr - 239/9*ca*cf*tr + 899/27*ca^2*tr)*ns
                         + (136/9*cf*tr^2 - 50/27*ca*tr^2)*ns^2);

setbetaSUSY[ng_,nf_,ns_] := {b0 -> beta[0,ng,nf,ns],
			     b1 -> beta[1,ng,nf,ns],
			     b2 -> beta[2,ng,nf,ns]}/.num1;

(*--#] *)

(*--#] *)
(*--#[ include results: *)

PrintVerb["Include results from ",respath];
PrintVerb["Include results from ",respathexact];

Get[respath<>"/izetag2.A1.m"];
Get[respath<>"/izetag2.A2.m"];
Get[respath<>"/izetag2.B2.m"];
Get[respath<>"/izetag2.C1.m"];
Get[respath<>"/izetag2.C2.m"];
Get[respath<>"/izetag2.D.m"];
(* Get[respathexact<>"/izetag2.1l.m"];                                *)
Get[respathexact<>"/izetag_exact.m"];

(*added by kantp to enable on-shell -> drbar transition of mtop *)
Get[Global`H3Prefix<>"/RunDec/include/izeta2lmtdr"];
izetamt = (1/zetamt2l) /. {xthf -> 1, cA -> 3, cR -> 4/3, TT -> 1/2, Numfq -> 5, Numft -> 1, z2 -> Zeta[2] };

izetag2[1,"A1"] = izetag2A11ldr/.{ep->0}/.{nsq->5};
izetag2[2,"A1"] = izetag2A12ldr/.{nsq->5};
izetag2[1,"A2"] = izetag2A21ldr/.{ep->0};
izetag2[2,"A2"] = izetag2A22ldr;


izetag2[1,"B1"] = izetag2A11ldr/.{ep->0}/.{nsq->6};
izetag2[2,"B1"] = izetag2A12ldr/.{nsq->6};
izetag2[1,"B2"] = izetag2B21ldr/.{ep->0};
izetag2[2,"B2"] = izetag2B22ldr;

izetag2[1,"C1"] = izetag2C11ldr/.{ep->0}/.{nsq->6};
izetag2[2,"C1"] = izetag2C12ldr/.{nsq->6};
izetag2[1,"C2"] = izetag2C21ldr/.{ep->0};
izetag2[2,"C2"] = izetag2C22ldr;

izetag2[1,"D"] = izetag2D1ldr/.{ep->0}/.{nsq->6};
izetag2[2,"D"] = izetag2D2ldr/.{nsq->6};

(* izetag2[1,"exact"] = izetag21ldr/.{ep->0,nsq->5};                 *)

(*--#] *)
(*--#[ AlphasSUSY[] (running of \alpha_s): *)
(*
- Contains also the running for pure QCD
- Note: here DR-bar version of beta function is used; even for 
  pure QCD there is a difference starting from \beta_2
*)
AlphasSUSY[alphasmu0_,mu0_,muend_,nnf_,nns_,nng_,loops_] := Module[
    {rhs,solx,a,x,lambda},
    If[(loops<0)||(loops>3), 
       Print["PROCEDURE AlphasSUSY IS NOT IMPLEMENTED FOR ",
	     loops," LOOPS."];
       Return[];];
    lambda = LamExpl[alphasmu0,mu0,nnf,loops];
    If[ N[muend/lambda] < rmulam ,
	Print["WARNING: the ratio \\mu/\\Lambda = ",
	      N[muend/lambda]," is very small!"];
    ];
    If[ mu0 == muend , Return[alphasmu0] ];
    If[ loops==0, Return[alphasmu0] ];
    If[ loops==1, rhs = -a[x]^2*(b0) ];
    If[ loops==2, rhs = -a[x]^2*(b0 + b1*a[x]) ];
    If[ loops==3, rhs = -a[x]^2*(b0 + b1*a[x] + b2*a[x]^2) ];
    sol = N[(Pi*a[x]/.
	     NDSolve[{a[mu0^2]==alphasmu0/Pi,
		      x*a'[x] == rhs/.setbetaSUSY[nng,nnf,nns]}, 
		     a[x], 
		     {x,muend^2,mu0^2},
		     WorkingPrecision->26,
		     AccuracyGoal->16,
		     PrecisionGoal->16,
		     MaxSteps->5000]
	     /.x->muend^2)[[1]],$NumPrec];
    Return[sol];
];

(*--#] *)
(*--#[ Asp2As[] *)
Asp2As[alphasmu_,mun_,s2thetatn_,nloops_,masses_List] := Module[
    {massrep,massesdef,alsrep,reprule},
    massesdef = {Global`Msquark -> -1,
		 Global`Mgluino -> -1,
		 Global`Mstop1  -> -1,
		 Global`Mstop2  -> -1,
		 Global`Mtop    -> -1};
    alsrep = {als4pi -> alphasmu/4/Pi};
    massrep = {RunDecSUSY`Private`Msquark -> Global`Msquark,
	       RunDecSUSY`Private`Mgluino -> Global`Mgluino,
	       RunDecSUSY`Private`Mstop1  -> Global`Mstop1,
	       RunDecSUSY`Private`Mstop2  -> Global`Mstop2,
	       RunDecSUSY`Private`Mtop    -> Global`Mtop
	       }/.masses;
    masseslabel = {Msquark,Mgluino,Mstop1,Mstop2,Mtop}/.massrep/.massesdef;
    If[ ( (masseslabel[[1]]) =!= -1 ) && ( (masseslabel[[2]]) == -1 ) &&
            ( (masseslabel[[3]]) == -1 )  && ( (masseslabel[[4]]) == -1 ) && 
                ( (masseslabel[[5]]) == -1 ) ,
        case = "A1";
    ];
    If[ ( (masseslabel[[1]]) == -1 )  && ( (masseslabel[[2]]) =!= -1 ) &&
            ( (masseslabel[[3]]) =!= -1 ) && ( (masseslabel[[4]]) =!= -1 ) &&
                ( (masseslabel[[5]]) =!= -1 ) ,
        case = "A2";
    ];
    If[ ( (masseslabel[[1]]) =!= -1 ) && ( (masseslabel[[2]]) == -1 ) &&
            ( (masseslabel[[3]]) =!= -1 ) && ( (masseslabel[[4]]) =!= -1 ) && 
                ( (masseslabel[[5]]) == -1 ) ,
        case = "B1";
    ];
    If[ ( (masseslabel[[1]]) == -1 )  && ( (masseslabel[[2]]) =!= -1 ) &&
            ( (masseslabel[[3]]) == -1 )  && ( (masseslabel[[4]]) == -1 ) &&
                ( (masseslabel[[5]]) =!= -1 ) ,
        case = "B2";
    ];
    If[ ( (masseslabel[[1]]) =!= -1 ) && ( (masseslabel[[2]]) =!= -1 ) &&
            ( (masseslabel[[3]]) =!= -1 ) && ( (masseslabel[[4]]) =!= -1 ) && 
                ( (masseslabel[[5]]) == -1 ) ,
        case = "C1";
    ];
    If[ ( (masseslabel[[1]]) == -1 ) && ( (masseslabel[[2]]) == -1 ) &&
            ( (masseslabel[[3]]) == -1 ) && ( (masseslabel[[4]]) == -1 ) &&
                ( (masseslabel[[5]]) =!= -1 ) ,
        case = "C2";
    ];
    If[ ( (masseslabel[[1]]) =!= -1 ) && ( (masseslabel[[2]]) =!= -1 ) &&
            ( (masseslabel[[3]]) =!= -1 ) && ( (masseslabel[[4]]) =!= -1 ) && 
                ( (masseslabel[[5]]) =!= -1 ) ,
        case = "D";
    ];
(*     If [ nloops == 1, case = "exact" ];                           *)
    PrintVerb["Asp2As::case: ",case];
    reprule = Join[phidenrep/.massrep,num1,num2,massrep,
		   logrep,{mu->mun,mu2->mun^2,s2thetat->s2thetatn},alsrep];
    (* A1: \alpha_s -> \alpha_s(\tilde{t},\tilde{g},6) *)
    If[nloops == 0 , Return[4*Pi*als4pi//.reprule] ];
    If[nloops == 1 , Return[4*Pi*als4pi*izetag2[1,case]//.reprule] ];
    If[nloops == 2 , Return[4*Pi*als4pi*izetag2[2,case]//.reprule] ];
];

(*--#] *)
(*--#[ Asp2AsExact[] *)
Asp2AsExact[alphasmu_,mun_,s2thetatn_,nloops_,masses_List, Xtval_] := Module[
    {massrep,massesdef,alsrep,reprule},
    massesdef = {Global`Msquark -> -1,
		 Global`Mgluino -> -1,
		 Global`Mstop1  -> -1,
		 Global`Mstop2  -> -1,
		 Global`Mtop    -> -1};
    alsrep = {als4pi -> alphasmu/4/Pi};
    massrep = {RunDecSUSY`Private`Msquark -> Global`Msquark,
	       RunDecSUSY`Private`Mgluino -> Global`Mgluino,
	       RunDecSUSY`Private`Mstop1  -> Global`Mstop1,
	       RunDecSUSY`Private`Mstop2  -> Global`Mstop2,
	       RunDecSUSY`Private`Mtop    -> Global`Mtop
	       }/.masses;
    masseslabel = {Msquark,Mgluino,Mstop1,Mstop2,Mtop}/.massrep/.massesdef;
    case = "exact";
    PrintVerb["Asp2AsExact::case: ",case];
    reprule = Join[phidenrep/.massrep,num1,num2,massrep,
		   logrep,{mu->mun,mu2->mun^2,s2thetat->s2thetatn,Xt->Xtval},alsrep];
    (* A1: \alpha_s -> \alpha_s(\tilde{t},\tilde{g},6) *)
    If[nloops == 0 , Return[4*Pi*als4pi//.reprule] ];
    If[nloops == 1 , Return[4*Pi*als4pi*izetag2[1,case]//.reprule] ];
(*     If[nloops == 2 , Return[4*Pi*als4pi*izetag2[2,case]//.reprule] ]; *)
    If[nloops == 2 ,
       mindist = 10;
       Mtopoff = 50;
       boolexpr[bMtop_] := (Abs[(Mgluino - Mstop2 + bMtop) /. reprule] > mindist) &&
        	           (Abs[(Mgluino - Mstop2 - bMtop) /. reprule] > mindist) &&
	                   (Abs[(Mgluino - Mstop1 + bMtop) /. reprule] > mindist) &&
	                   (Abs[(Mgluino - Mstop1 - bMtop) /. reprule] > mindist);
(* ***
         Print["xdecSUSY: ",(Mgluino - Mstop2 + Mtop) /. reprule];	   
         Print["xdecSUSY: ",(Mgluino - Mstop2 - Mtop) /. reprule];	   
         Print["xdecSUSY: ",(Mgluino - Mstop1 + Mtop) /. reprule];	   
         Print["xdecSUSY: ",(Mgluino - Mstop1 - Mtop) /. reprule]; 
*** *)
       If[ boolexpr[Mtop],
	   Return[4*Pi*als4pi*izetag2[2,case]//.reprule] 
	   ,
(*  	   Print["interpol"];					   *)
	   Mtopoffup = Mtopoff;
	   Mtopoffdo = Mtopoff;
           While[Not[boolexpr[Mtop+Mtopoffup]],Mtopoffup = Mtopoffup+mindist];
           While[Not[boolexpr[Mtop-Mtopoffdo]],Mtopoffdo = Mtopoffdo+mindist];
	   extmp1 = izetag2[2,case]/.{Mtop->Mtop+Mtopoffup}//.reprule;
	   extmp2 = izetag2[2,case]/.{Mtop->Mtop-Mtopoffdo}//.reprule;
(* ***
	   Print[Mtopoffup," :: ",Mtopoffdo];
   	   Print["xdecSUSY: ",Mtop," ",extmp1," ",extmp2];		   
  	   Print["xdecSUSY: ",4*Pi*als4pi*1/2*(extmp1+extmp2)];	  
*** *)
	   Return[4*Pi*als4pi*1/2*(extmp1+extmp2)/.reprule] 
       ];
   ];
];

(*--#] *)

End[]

EndPackage[]

(*--#] *)

(* ------------------------------------------------------------ *)

(* *****
<<RunDec.m;<<decSUSY.m

(asMznum := 0.120;Print[ as1=asILC[muth2def,3,"C"]];asMznum := 0.120)
(asMznum := 0.122;Print[ as2=asILC[muth2def,3,"C"]];asMznum := 0.120)
(asMznum := 0.118;Print[ as3=asILC[muth2def,3,"C"]];asMznum := 0.120)
{as1,as1-as2,as1-as3}

(asMznum := 0.120;Print[ as1=asPL[muth1def,muth2def,3,"C"] ];asMznum := 0.120)
(asMznum := 0.122;Print[ as2=asPL[muth1def,muth2def,3,"C"] ];asMznum := 0.120)
(asMznum := 0.118;Print[ as3=asPL[muth1def,muth2def,3,"C"] ];asMznum := 0.120)
(asMznum := 0.120;Print[ as4=asPL[muth1def,muth2def,2,"C"] ];asMznum := 0.120)
{as1,as1-as2,as1-as3,as1-as4}

asMznum := 0.1187
asDRTMP1[as_]:=asDR[as,5,1]
asDRTMP2[as_]:=asDR[as,5,2]
Map[asDRTMP1,{asMznum,asMznum-0.002,asMznum+0.002}]
Map[asDRTMP2,{asMznum,asMznum-0.002,asMznum+0.002}]

(*--#[ generate data: *)

(* 
\alpha_s(M_GUT) as a function of \mu_th1
format: \mu_th1 asA1l asA2l asA3l (B) (C) (D)
*)
(gendata[{muth1,
    Hold[asPL[muth1,muth2def,1,"A"]],
    Hold[asPL[muth1,muth2def,2,"A"]],
    Hold[asPL[muth1,muth2def,3,"A"]],
    Hold[asPL[muth1,muth2def,1,"B"]],
    Hold[asPL[muth1,muth2def,2,"B"]],
    Hold[asPL[muth1,muth2def,3,"B"]],
    Hold[asPL[muth1,muth2def,1,"C"]],
    Hold[asPL[muth1,muth2def,2,"C"]],
    Hold[asPL[muth1,muth2def,3,"C"]],
    Hold[asPL[muth1,         1,"D1"]],
    Hold[asPL[muth1,         2,"D1"]],
    Hold[asPL[muth1,         3,"D1"]]
},{muth1,100,10000},10,"data/asplth1abcd.dat"])

(* 
\alpha_s(M_GUT) as a function of \mu_th2
format: \mu_th2 asA1l asA2l asA3l (B) (C) (D)
*)
(gendata[{muth2,
    Hold[asPL[muth1def,muth2,1,"A"]],
    Hold[asPL[muth1def,muth2,2,"A"]],
    Hold[asPL[muth1def,muth2,3,"A"]],
    Hold[asPL[muth1def,muth2,1,"B"]],
    Hold[asPL[muth1def,muth2,2,"B"]],
    Hold[asPL[muth1def,muth2,3,"B"]],
    Hold[asPL[muth1def,muth2,1,"C"]],
    Hold[asPL[muth1def,muth2,2,"C"]],
    Hold[asPL[muth1def,muth2,3,"C"]],
    Hold[asPL[         muth2,1,"D2"]],
    Hold[asPL[         muth2,2,"D2"]],
    Hold[asPL[         muth2,3,"D2"]]
},{muth2,40,4000},10,"data/asplth2abcd.dat"])

(* 
\alpha_s(M_ILC) as a function of \mu_th1
format: \mu_th1 asC1l asC2l asC3l
*)
(gendata[{muth2,
    Hold[asILC[muth2,1,"C"]],
    Hold[asILC[muth2,2,"C"]],
    Hold[asILC[muth2,3,"C"]]
},{muth2,40,4000},10,"data/asilcth2c.dat"])
(* ***
(gendata[{muth2,
    Hold[asILC[muth2,1,"A"]],
    Hold[asILC[muth2,2,"A"]],
    Hold[asILC[muth2,3,"A"]]
},{muth2,40,4000},10,"data/asilcth2a.dat"])
*** *)


(* 
\alpha_s(\mu) for Mz <= \mu <= \mu^GUT
format: \mu asA1l asA2l asA3l (B) (C) (D)
*)

asMznum

(
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1201.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1202.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1203.dat"])
)

(asMznum := 0.122;
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1221.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1222.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1223.dat"]);
asMznum := 0.120;)

(asMznum := 0.118;
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1181.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1182.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"A"]],Hold[asmu[Exp[lmu],2,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]],
    Hold[asmu[Exp[lmu],1,"B"]],Hold[asmu[Exp[lmu],2,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]],
    Hold[asmu[Exp[lmu],1,"C"]],Hold[asmu[Exp[lmu],2,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]],
    Hold[asmu[Exp[lmu],1,"D1"]],Hold[asmu[Exp[lmu],2,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]],
    Hold[asmu[Exp[lmu],1,"D2"]],Hold[asmu[Exp[lmu],2,"D2"]],
    Hold[asmu[Exp[lmu],3,"D2"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1183.dat"]);
asMznum := 0.120;)

(* for "D3": *)

(
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1201d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1202d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1203d3.dat"])
)

(asMznum := 0.122;
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1221d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1222d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1223d3.dat"]);
asMznum := 0.120;)

(asMznum := 0.118;
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[Mz/.NumDef],Log[MSUSY2-10]},50,"data/asmuabcd1181d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY2+10],Log[MSUSY1-10]},50,"data/asmuabcd1182d3.dat"]);
(gendata[{Exp[lmu],
    Hold[asmu[Exp[lmu],1,"D3"]],Hold[asmu[Exp[lmu],2,"D3"]],
    Hold[asmu[Exp[lmu],3,"D3"]]
},{lmu,Log[MSUSY1+10],Log[3 * muPLdef]},50,"data/asmuabcd1183d3.dat"]);
asMznum := 0.120;)




(* *** NOT USED:
(* 
\alpha_s(\mu) for Mz <= \mu <= \mu^GUT
format: \mu asA2l/asA1l asA3l/asA1l (B) (C) (D)
*)

(gendata[{lmu,
    Hold[asmu[Exp[lmu],2,"A"]]/Hold[asmu[Exp[lmu],1,"A"]],
    Hold[asmu[Exp[lmu],3,"A"]]/Hold[asmu[Exp[lmu],1,"A"]],
    Hold[asmu[Exp[lmu],2,"B"]]/Hold[asmu[Exp[lmu],1,"B"]],
    Hold[asmu[Exp[lmu],3,"B"]]/Hold[asmu[Exp[lmu],1,"B"]],
    Hold[asmu[Exp[lmu],2,"C"]]/Hold[asmu[Exp[lmu],1,"C"]],
    Hold[asmu[Exp[lmu],3,"C"]]/Hold[asmu[Exp[lmu],1,"C"]],
    Hold[asmu[Exp[lmu],2,"D1"]]/Hold[asmu[Exp[lmu],1,"D1"]],
    Hold[asmu[Exp[lmu],3,"D1"]]/Hold[asmu[Exp[lmu],1,"D1"]]
},{lmu,Log[Mz/.NumDef],Log[muGUTdef]},50,"data/asmuabcd.dat"])
*** *)

(*--#] *)

(* ------------------------------------------------------------ *)

(*--#[ some checks: *)

(* Compare: *)
AlphasExact[0.118, 91.18, 300, 5,     2]
AlphasSUSY[ 0.118, 91.18, 300, 5,1,0, 1]

?Asp2As
?AlphasSUSY

(* cases A-D: *)
Asp2As[0.1,1000.,.1,2,{Msquark->900.}]
Asp2As[0.1,1000.,.1,2,{Mgluino->500.,Mstop1->300.,Mstop2->400.,Mtop->175.}]
Asp2As[0.1,1000.,.1,2,{Msquark->500.,Mstop1->300.,Mstop2->400.}]
Asp2As[0.1,1000.,.1,2,{Mgluino->500.,Mtop->175.}]
Asp2As[0.1,1000.,.1,1,{Msquark->500.,Mgluino->400.,Mstop1->300.,Mstop2->400.}]
Asp2As[0.1,1000.,.1,1,{Mtop->175.}]
Asp2As[0.1,1000.,.1,1,{Msquark->900.,Mgluino->500.,Mstop1->300.,Mstop2->400.,Mtop->175.}]

(* ------------------------------------------------------------ *)

(* ----- *)

?asPL
?muGUTdef

{asPL[400,3,"D1"],asPL[400,3,"D2"],asPL[400,3,"D3"]}
%-asPL[400,1000,3,"C"]

asPL[3100,1,"D1"]
asPL[3100,2,"D1"]
asPL[3100,3,"D1"]

asPL[200,3100,1,"A"]
asPL[200,3100,1,"B"]
asPL[200,3100,1,"C"]
asPL[200,3100,2,"A"]
asPL[200,3100,3,"A"]
asPL[200,3100,3,"B"]
asPL[200,3100,3,"C"]

asILC[800,2,"A"]
asILC[800,2,"C"]

asmu[91.18,3,"A"]
asmu[91.18,3,"D"]
asmu[500,1,"D"]
asmu[2000,1,"B"]

(*--#] *)
(*--#[ Mathematica plots: *)

(* 3D plots *)

(* \alpha_s(\mu_GUT) as a function of \mu_th1 and \mu_th2 *)

(case = "C";
(plt1 = Plot3D[ asPL[mu2,mu1,1,case], {mu2,40,4000} , 
		{mu1,100,10000},ColorFunction->myCol1,
		ViewPoint -> {1.3, -1.4, .5}]);
(plt2 = Plot3D[ asPL[mu2,mu1,2,case], {mu2,40,4000} , 
		{mu1,100,10000},ColorFunction->myCol2 ]);
(plt3 = Plot3D[ asPL[mu2,mu1,3,case], {mu2,40,4000} , 
		{mu1,100,10000},ColorFunction->myCol3 ]);
)

(* strongest variation in %: *)
(asPL[40,100,1,case] - asPL[4000,10000,1,case])/asPL[400,1000,1,case]
(asPL[40,100,2,case] - asPL[4000,10000,2,case])/asPL[400,1000,2,case]
(asPL[40,100,3,case] - asPL[4000,10000,3,case])/asPL[400,1000,3,case]

(asPL[40,100,3,case] - asPL[4000,10000,3,case])


plt = Show[plt1,plt2,plt3]
plt = Show[plt1,plt2,plt3,PlotRange->{.037,0.042}]

Display["!psfix > figs/asC.ps", plt ]; 

Display["!psfix > figs/asA.ps", plt ]; 
Display["!psfix > figs/asB.ps", plt ]; 

(* ----- *)

(* 2D plots *)

(* 1/\alpha_s(\mu) *)

(pl1 = Plot[{1/asmu[Exp[lmu],1,"A"],
	     1/asmu[Exp[lmu],2,"A"],
	     1/asmu[Exp[lmu],3,"A"]
     },{lmu,Log[100],Log[10^16]},PlotRange->{7,27}])

(pl4 = Plot[1/asmu[Exp[lmu],3,"D1"]
	    ,{lmu,Log[100],Log[10^16]},PlotRange->{7,27},
	    PlotStyle->Dashing[{0.06, 0.06}]])


(asMznum := 0.120; pl2 = Plot[1/asmu[Exp[lmu],3,"A"]
			   ,{lmu,Log[100],Log[10^16]},PlotRange->{7,27},
	    PlotStyle->Dashing[{0.03, 0.03}]];
asMznum := 0.118;)


(asMznum := 0.116;pl3 = Plot[1/asmu[Exp[lmu],3,"A"]
			     ,{lmu,Log[100],Log[10^16]},PlotRange->{7,27},
			     PlotStyle->Dashing[{0.03, 0.03}]];
asMznum := 0.118;)

plt = Show[pl1,pl2,pl3,pl4]

Display["!psfix > figs/asmua.ps", plt ]; 


(
case = "D";
plt = Plot[ {asPL[mu,1,case],asPL[mu,2,case],asPL[mu,3,case]} , 
	    {mu,100,10000} ,
	    PlotStyle -> {Dashing[{0.01, 0.01}],
			  Dashing[{0.03, 0.03}],
			  Dashing[{1.0, 0.0}]   } ]
)

Display["!psfix > asD.ps", plt ]; 

,PlotRange->{0.060,0.080} ]

plt = Plot[ {1/asPL[300,Exp[mu],1,case],1/asPL[300,Exp[mu],2,case],
	     1/asPL[300,Exp[mu],3,case]}, 
	    {mu,Log[100],Log[10000]} ,
  PlotStyle -> {Dashing[{0.01, 0.01}],
		Dashing[{0.03, 0.03}],
		Dashing[{1.0, 0.0}]   } ]

(* *** TMP: Plot3D and colours: 
pl1 = Plot3D[Sin[x+y],{x,-Pi,Pi},{y,-Pi,Pi},Mesh->False,ColorFunction->(GrayLevel[#^1]&)]
pl1 = Plot3D[Sin[x+y],{x,-Pi,Pi},{y,-Pi,Pi},Mesh->False,ColorFunction->myCol1]
pl2 = Plot3D[Cos[x+y],{x,-Pi,Pi},{y,-Pi,Pi},Mesh->False,ColorFunction->myCol3]

pl2 = Plot3D[Cos[x+y],{x,-Pi,Pi},{y,-Pi,Pi},AxesLabel -> {"mu1", "mu2", "alpha_s"}]

Show[pl2,pl1]

myCol1[x_] := CMYKColor[0,0,x,x]
myCol2[x_] := RGBColor[0,x,0]
myCol3[x_] := RGBColor[0,0,x]
myHue[x_] := Hue[x,.5,1]
*** *)

(*--#] *)


Get["zeta_appro/izetag2.C1.m"];
Get["zeta_appro/izetag2.C2.m"];

ex1 = (izetag2C12ldr/.{als4pi->als4pi6})
ex2 = (izetag2C22ldr/.{als4pi->als4pi5})

(Collect[Expand[ex2 * (ex1/.{als4pi6->als4pi5*ex2})]
/.als4pi5->api/4,{api,lMsquark,lMtop},Expand])


***** *)

(* ------------------------------------------------------------ *)

(*--#[ misc. definitions: *)

s2thetatdef := 0.1;
muGUTdef := 10^16;
muPLdef := 10^19;
muILC := 800.;

MSUSY1  := 1000.; 
MSUSY2  := 400.; 
MSUSY3  := 2000.; 
Mtopdef := 174.;

muth1def = MSUSY1;
muth2def = MSUSY2;

(* \alpha_s(Mz)-DR-bar: *)
asMznum := 0.120;  

NumDef := {asMz -> asMznum, Mz -> 91.18, Mt -> Mtopdef, 
	   Mb -> 4.7, Mc -> 1.6, muc -> 1.2,  mub -> 3.97, Mtau -> 1.777};

(* SetOptions[Plot3D, PlotPoints->15];                               *)
(* SetOptions[Plot, PlotDivision->5];                                *)

myCol1[x_] := RGBColor[0,.6*x+.4,0];
myCol2[x_] := RGBColor[0,0,.6*x+.4];
myCol3[x_] := RGBColor[.6*x+.4,0,0];

(*--#] *)
(*--#[ \alpha_s(mu), etc.: *)

(* 
\alpha_s^(5)(Mz) -> \alpha_s^(SUSY)(muend); 
matching at 'muth1'; 'nloops' refers to running
case D: SUSY == full
*)
(asMz2asmu[muend_,muth1_,nloops_,case_String] := Module[
    {muPL,s2thetat,set2,nf,ns,ng},
    muPL = muend;
    s2thetat = s2thetatdef;
    If[case === "A",
       set2 = {Mgluino->MSUSY2,
	       Mstop1->MSUSY2,Mstop2->MSUSY2,Mtop->Mtopdef};
       nf = 6; ns = 1; ng = 1; 
   ];
    If[case === "B",
       set2 = {Mgluino->MSUSY2,Mtop->Mtopdef};
       nf = 6; ns = 0; ng = 1; 
   ];
    If[case === "C",
       set2 = {Mtop->Mtopdef};
       nf = 6; ns = 0; ng = 0; 
   ];
    If[case === "D1",
       set2 = {Msquark->MSUSY1,Mgluino->MSUSY1,
	       Mstop1->MSUSY1,Mstop2->MSUSY1,Mtop->Mtopdef};
       nf = 6; ns = 6; ng = 1; 
   ];
    If[case === "D2",
       set2 = {Msquark->MSUSY2,Mgluino->MSUSY2,
	       Mstop1->MSUSY2,Mstop2->MSUSY2,Mtop->Mtopdef};
       nf = 6; ns = 6; ng = 1; 
   ];
    If[case === "D3",
       set2 = {Msquark->MSUSY3,Mgluino->MSUSY3,
	       Mstop1->MSUSY3,Mstop2->MSUSY3,Mtop->Mtopdef};
       nf = 6; ns = 6; ng = 1; 
   ];
    asmuth1in = AlphasSUSY[asMz/.NumDef, Mz/.NumDef, muth1, 5,0,0,nloops];
    asmuth1   = Asp2As[asmuth1in,muth1,s2thetat,nloops-1,set2]//Chop;
    Return[     AlphasSUSY[asmuth1,      muth1,      muPL,  nf,ns,ng,nloops]];
]);

(* 
\alpha_s^(5)(Mz) -> \alpha_s^(full)(muend); 
matching at 'muth1' and 'muth2'; 'nloops' refers to running
*)
(asMz2asmu[muend_,muth1_,muth2_,nloops_,case_String] := Module[
    {s2thetat,muPL,set1,set2,nf,ns,ng},
    muPL = muend;
    s2thetat = s2thetatdef;
    If[case === "A",
       set2 = {Mgluino->MSUSY2,
	       Mstop1->MSUSY2,Mstop2->MSUSY2,Mtop->Mtopdef};
       set1 = {Msquark->MSUSY1};
       nf = 6; ns = 1; ng = 1; 
   ];
    If[case === "B",
       set2 = {Mgluino->MSUSY2,Mtop->Mtopdef};
       set1 = {Msquark->MSUSY1,Mstop1->MSUSY1,Mstop2->MSUSY1};
       nf = 6; ns = 0; ng = 1; 
   ];
    If[case === "C",
       set2 = {Mtop->Mtopdef};
       set1 = {Msquark->MSUSY1,Mstop1->MSUSY1,Mstop2->MSUSY1,Mgluino->MSUSY1};
       nf = 6; ns = 0; ng = 0; 
   ];
    asmuth2in = AlphasSUSY[asMz/.NumDef, Mz/.NumDef, muth2, 5,0,0,nloops];
    asmuth2   = Asp2As[asmuth2in,muth2,s2thetat,nloops-1,set2]//Chop;
    asmuth1in = AlphasSUSY[asmuth2,      muth2,      muth1, nf,ns,ng,nloops];
    asmuth1   = Asp2As[asmuth1in,muth1,s2thetat,nloops-1,set1];
    Return[     AlphasSUSY[asmuth1,      muth1,      muPL,  6,6,1,nloops]];
]);

(asPL[muth1_,muth2_,nloops_,case_String] := 
 asMz2asmu[muGUTdef,muth1,muth2,nloops,case]);

(asPL[muth_,nloops_,case_String] := 
 asMz2asmu[muGUTdef,muth,nloops,case]);

(asILC[muth_,nloops_,case_String] := 
asMz2asmu[muILC,muth,nloops,case]);

(asmu[mu_,nloops_,case_String] := Module[
{},
If[mu <= muth2def,
  Return[AlphasSUSY[asMz/.NumDef, Mz/.NumDef, mu, 5,0,0,nloops]];
];
If[mu <= muth1def && (case =!= "D1") && (case =!= "D2") && (case =!= "D3"),
  Return[asMz2asmu[mu,muth2def,nloops,case]];
];
If[(case === "D2"),
  Return[asMz2asmu[mu,muth2def,nloops,case]];
];
If[(case === "D1") || (case === "D3"),
  If[mu <= muth1def,
    Return[AlphasSUSY[asMz/.NumDef, Mz/.NumDef, mu, 5,0,0,nloops]];
  ];
  Return[asMz2asmu[mu,muth1def,nloops,case]];
];
Return[asMz2asmu[mu,muth1def,muth2def,nloops,case]];
]);

(*--#] *)
(*--#[ gendata: *)

(*
Generate data file
Note: in the present version too large or too small
numers may be displayed in the wrong way.    

Example:
gendata[{x^2,x^3},{x,0,1},10,"data/test.dat"]
gendata[{x,Hold[asPL[x,1,"D"]],x^3},{x,1000,2000},10,"data/test.dat"]
*)

(gendata[ex_List,var_List,num_,name_String] := Module[
    {exn,exns,varact},
ofi = OpenWrite[name];
step = (var[[3]]-var[[2]])/(num-1);
For[varact=var[[2]],varact<=var[[3]],varact=varact+step,
    exn = ReleaseHold[ex/.{var[[1]]->N[varact]}];
    exn = Map[ FortranForm , exn ];
    exns = StringReplace[ ToString[exn], {","->"","{"->"","}"->""} ];
    WriteString[ofi,exns,"\n"];
];
Close[ofi];
]);

(*--#] *)
(*--#[ asMS -> asDR: *)

(*
2-loop relation from Z.Bern et al., PRD66/085002/2002, Eq.(8.12).
*)

(asDR[asMS_,nf_,nloops_] := Module[
    {},
    If[nloops==0,Return[asMS]];
    If[nloops==1,Return[asMS*(1 + asMS/Pi*3/12)]];
    If[nloops>2,Print["asDR: not implemented."];Abort[];];
    Return[asMS*(1 + asMS/Pi*3/12 + (asMS/Pi)^2*(11/72*9-nf*1/8*4/3*1/2))];
]);

(*--#] *)
